about summary refs log tree commit diff stats
path: root/030---translate.cc
diff options
context:
space:
mode:
authorKartik Agaram <vc@akkartik.com>2020-01-02 01:41:55 -0800
committerKartik Agaram <vc@akkartik.com>2020-01-02 02:01:41 -0800
commit9e5e87ca3776efa5f0d772ed8cf348bf6ee4d08e (patch)
tree5134d5ff1629cb5262e5feda38831456a2d1467d /030---translate.cc
parentdf8498fb8294cb07d02076cf3881617b5af07974 (diff)
downloadmu-9e5e87ca3776efa5f0d772ed8cf348bf6ee4d08e.tar.gz
5865
Give the bootstrap C++ program a less salient name.
Diffstat (limited to '030---translate.cc')
-rw-r--r--030---translate.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/030---translate.cc b/030---translate.cc
index b950fce7..3c4c7f2f 100644
--- a/030---translate.cc
+++ b/030---translate.cc
@@ -10,10 +10,10 @@ if (is_equal(argv[1], "translate")) {
   // Outside of tests, traces must be explicitly requested.
   if (Trace_file.is_open()) Trace_stream = new trace_stream;
   reset();
   // Begin subx translate
   program p;
   string output_filename;
-  for (int i = /*skip 'subx translate'*/2;  i < argc;  ++i) {
+  for (int i = /*skip 'bootstrap translate'*/2;  i < argc;  ++i) {
     if (is_equal(argv[i], "-o")) {
       ++i;
       if (i >= argc) {
@@ -53,7 +53,7 @@ if (is_equal(argv[1], "translate")) {
     unlink(output_filename.c_str());
     return 1;
   }
   // End subx translate
   return 0;
 }
 
@@ -63,7 +63,7 @@ void transform(program& p) {
 }
 
 void print_translate_usage() {
-  cerr << "Usage: subx translate file1 file2 ... -o output\n";
+  cerr << "Usage: bootstrap translate file1 file2 ... -o output\n";
 }
 
 // write out a program to a bare-bones ELF file
@@ -10,10 +10,10 @@ if (is_equal(argv[1], "translate")) {
   if (Trace_file.is_open()) Trace_stream = new trace_stream;
   reset();
-  // Begin subx translate
+  // Begin bootstrap translate
   program p;
   string output_filename;
@@ -53,7 +53,7 @@ if (is_equal(argv[1], "translate")) {
     return 1;
   }
-  // End subx translate
+  // End bootstrap translate
   return 0;
 }